@@ -1,3 +1,4 @@
+//go:build !unittests
 // +build !unittests
 
 package __performance_update_test
@@ -11,13 +12,13 @@ import (
 	. "github.com/onsi/gomega"
 
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/klog"
 
 	ginkgo_reporters "kubevirt.io/qe-tools/pkg/ginkgo-reporters"
 
 	testutils "github.com/openshift-kni/performance-addon-operators/functests/utils"
 	testclient "github.com/openshift-kni/performance-addon-operators/functests/utils/client"
 	"github.com/openshift-kni/performance-addon-operators/functests/utils/junit"
+	testlog "github.com/openshift-kni/performance-addon-operators/functests/utils/log"
 	"github.com/openshift-kni/performance-addon-operators/functests/utils/namespaces"
 )
 
@@ -26,7 +27,7 @@ var _ = BeforeSuite(func() {
 	// create test namespace
 	err := testclient.Client.Create(context.TODO(), namespaces.TestingNamespace)
 	if errors.IsAlreadyExists(err) {
-		klog.Warning("test namespace already exists, that is unexpected")
+		testlog.Warning("test namespace already exists, that is unexpected")
 		return
 	}
 	Expect(err).ToNot(HaveOccurred())
